Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(700)

Unified Diff: net/ssl/ssl_config.h

Issue 1535363003: Switch to standard integer types in net/. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: stddef Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/ssl/ssl_client_session_cache_openssl.h ('k') | net/ssl/ssl_config_service_defaults.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/ssl/ssl_config.h
diff --git a/net/ssl/ssl_config.h b/net/ssl/ssl_config.h
index 60f3dd10cd808969ccdcf2ab5a6d4039ac05e15b..5460f6640ef72c6675cec4c0e5fee6d3baae73e5 100644
--- a/net/ssl/ssl_config.h
+++ b/net/ssl/ssl_config.h
@@ -15,10 +15,10 @@
namespace net {
// Various TLS/SSL ProtocolVersion values encoded as uint16
// struct {
-// uint8 major;
-// uint8 minor;
+// uint8_t major;
+// uint8_t minor;
// } ProtocolVersion;
// The most significant byte is |major|, and the least significant byte
// is |minor|.
@@ -84,14 +84,14 @@ struct NET_EXPORT SSLConfig {
// (Use the SSL_PROTOCOL_VERSION_xxx enumerators defined above.)
// SSL 2.0 and SSL 3.0 are not supported. If version_max < version_min, it
// means no protocol versions are enabled.
- uint16 version_min;
- uint16 version_max;
+ uint16_t version_min;
+ uint16_t version_max;
// version_fallback_min contains the minimum version that is acceptable to
// fallback to. Versions before this may be tried to see whether they would
// have succeeded and thus to give a better message to the user, but the
// resulting connection won't be used in these cases.
- uint16 version_fallback_min;
+ uint16_t version_fallback_min;
// Presorted list of cipher suites which should be explicitly prevented from
// being used in addition to those disabled by the net built-in policy.
@@ -109,12 +109,12 @@ struct NET_EXPORT SSLConfig {
// The ciphers listed in |disabled_cipher_suites| will be removed in addition
// to the above list.
//
- // Though cipher suites are sent in TLS as "uint8 CipherSuite[2]", in
+ // Though cipher suites are sent in TLS as "uint8_t CipherSuite[2]", in
// big-endian form, they should be declared in host byte order, with the
- // first uint8 occupying the most significant byte.
+ // first uint8_t occupying the most significant byte.
// Ex: To disable TLS_RSA_WITH_RC4_128_MD5, specify 0x0004, while to
// disable TLS_ECDH_ECDSA_WITH_RC4_128_SHA, specify 0xC002.
- std::vector<uint16> disabled_cipher_suites;
+ std::vector<uint16_t> disabled_cipher_suites;
// Enables deprecated cipher suites. These cipher suites are selected under a
// fallback to distinguish servers which require them from servers which
« no previous file with comments | « net/ssl/ssl_client_session_cache_openssl.h ('k') | net/ssl/ssl_config_service_defaults.h » ('j') | no next file with comments »
@@ -15,10 +15,10 @@
namespace net {
-// Various TLS/SSL ProtocolVersion values encoded as uint16
+// Various TLS/SSL ProtocolVersion values encoded as uint16_t
// struct {

Powered by Google App Engine
This is Rietveld 408576698